@@ -17,6 +17,8 @@ $VERSION = '0.09';
 
 @ISA = qw(Safe::Hole) ;
 
+no warnings ;
+
 ###########
 # REQUIRE #
 ###########
@@ -70,6 +72,8 @@ sub call_09_fix {
   return $wantarray ? @r : $r[0] ;
 }
 
+sub DESTROY {}
+
 #######
 # END #
 #######
